<template>
  <div class="app-container">
    <el-form :model="queryParams" ref="queryRef"  class="evenly-distributed-labels" :inline="true" v-show="showSearch" label-width="80px" label-position="left">
      <el-form-item label="企业名称" prop="companyName">
        <el-input v-model="queryParams.companyName" placeholder="请输入企业名称" clearable style="width: 200px" @keyup.enter="handleQuery" />
      </el-form-item>
      <el-form-item label="联系人" prop="companyUser">
        <el-input v-model="queryParams.companyUser" placeholder="请输入联系人" clearable style="width: 200px" @keyup.enter="handleQuery" />
      </el-form-item>
      <el-form-item label="手机号" prop="companyPhone">
        <el-input v-model="queryParams.companyPhone" type="number" placeholder="请输入手机号" clearable style="width: 200px" @keyup.enter="handleQuery" />
      </el-form-item>
      <el-form-item>
        <el-button type="primary" icon="Search" @click="handleQuery">搜索</el-button>
        <el-button icon="Refresh" @click="resetQuery">重置</el-button>
      </el-form-item>
    </el-form>
    <el-table
      v-if="refreshTable"
      v-loading="loading"
      :data="deptList"
      row-key="deptId"
      :default-expand-all="isExpandAll"
      :tree-props="{ children: 'children', hasChildren: 'hasChildren' }"
    >
      <el-table-column  prop="companyName" label="企业名称" minWidth="300"></el-table-column>
      <!-- <el-table-column prop="companyName" label="企业类型" width="200"></el-table-column> -->
      <el-table-column prop="companyUser" label="联系人" width="180"></el-table-column>
      <el-table-column prop="companyPhone" label="手机号码" width="120"></el-table-column>
      <el-table-column prop="comeTime" label="创建时间" width="200"></el-table-column>
      <el-table-column prop="comeContent" label="来访事项" width="200"></el-table-column>
      <el-table-column prop="userNum" label="随行人数" width="200"></el-table-column>
      <el-table-column prop="remark" label="备注" ></el-table-column>
      <el-table-column label="操作" align="center" fixed="right" class-name="small-padding fixed-width" width="240">
        <template #default="scope">
          <el-link type="success" v-if="scope.row.checkStatus < 2" v-hasPermi="['sys:company:check']" @click="checkJudge(scope.row)">审核</el-link>
          <el-divider direction="vertical" v-hasPermi="['sys:company:check']" v-if="scope.row.checkStatus < 2"/>
          <el-link type="info" v-if="scope.row.checkStatus == 2" @click="createQrcodeHandler(scope.row)">二维码</el-link>
          <el-divider direction="vertical"  v-if="scope.row.checkStatus == 2"/>
          <el-link type="primary" @click="handleAdd(scope.row)">编辑</el-link>
          <el-divider direction="vertical" />
          <el-link type="error" @click="handleDelete(scope.row)">删除</el-link>
         </template>
      </el-table-column>
    </el-table>
    <pagination v-show="queryParams.total > 0" :total="queryParams.total" v-model:page="queryParams.pageNum" v-model:limit="queryParams.pageSize" @pagination="getList" />

    <!-- 添加或修改对话框 -->
    <el-dialog :title="title" v-model="open" width="600px" append-to-body>
      <el-form ref="deptRef" :model="form" :rules="rules" label-width="140px">
        <el-form-item label="企业名称" prop="companyName">
          <el-input placeholder="请输入企业名称" v-model="form.companyName"></el-input>
        </el-form-item>
        <el-form-item label="联系人"  prop="companyUser">
          <el-input placeholder="请输入联系人" v-model="form.companyUser"></el-input>
        </el-form-item>
        <el-form-item label="手机号码" prop="companyPhone">
          <el-input  placeholder="请输入手机号码" v-model="form.companyPhone"></el-input>
        </el-form-item>
        <el-form-item label="来访人员" prop="comeUser">
          <el-input  placeholder="请输入" v-model="form.comeUser"></el-input>
        </el-form-item>
        <el-form-item label="来访事项" prop="comeContent">
          <el-input  placeholder="请输入" v-model="form.comeContent"></el-input>
        </el-form-item>
        <el-form-item label="随行人数" prop="userNum">
          <el-input  placeholder="请输入" v-model="form.userNum"></el-input>
        </el-form-item>
        <el-form-item label="备注">
          <el-input placeholder="请输入备注" v-model="form.remark"></el-input>
        </el-form-item>
      </el-form>
      <template #footer>
        <div class="dialog-footer">
          <el-button type="primary" @click="submitForm">确 定</el-button>
          <el-button @click="cancel">取 消</el-button>
        </div>
      </template>
    </el-dialog>
    <exportExcelCom ref="exporttem" @resList="resList"></exportExcelCom>
    <exportRecord ref="exportRecordCom" :recordRow="recordRow" @uploadList="getList"></exportRecord>
    <judgeCom ref="judgeComRef" @upload="getList"></judgeCom>
    <createQrcode ref="createQrcodeRef"></createQrcode>
  </div>
</template>

<script setup name="Dept">
import FileUpload from '@/components/ImageUpload/index'
import exportRecord from './components/exportRecord'
import createQrcode from './components/createQrcode'
import judgeCom from './components/judge'
import { listCompanyLog,addCompany, updStatus, delCompanyLog, updCompanyLog } from "@/api/system/company/company";
import exportExcelCom from './components/export'
import { computed } from "vue";
import { judgeStatus, companyStatus, scopeList } from '@/utils/mapList/index.ts'
import useSettingsStore from "@/store/modules/settings";
const thcolor = computed(() => useSettingsStore().theme);
const { proxy } = getCurrentInstance();
const { sys_normal_disable } = proxy.useDict("sys_normal_disable");
const deptList = ref([]);
const open = ref(false);
const loading = ref(true);
const showSearch = ref(true);
const title = ref("");
const deptOptions = ref([]);
const isExpandAll = ref(false);
const refreshTable = ref(true);
const exporttem = ref()
const exportRecordCom = ref()
const judgeComRef = ref()
const createQrcodeRef = ref()
const options = reactive({
  // -1拒绝，0待审批，1审批中，2通过	
  checkOptions: [
    {
      label: '拒绝',
      value: -1
    },
    {
      label: '待审批',
      value: 0
    },
    {
      label: '审批中',
      value: 1
    },
    {
      label: '通过',
      value: 2
    }
  ],
  companyStatus: [
  {
      label: '正常',
      value: 0
    },
    {
      label: '禁用',
      value: 1
    },
  ],
  socreList: [
  {
      label: '导入',
      value: 1
    },
    {
      label: '注册',
      value: 0
    },
  ]
})
const data = reactive({
  form: {},
  queryParams: {
    deptName: undefined,
    status: undefined,
    deptType: undefined,
    pageNum: 1,
    pageSize: 10,
    total: 1
  },
  rules: {
    companyName: [{ required: true, message: "企业名称不能为空", trigger: "blur" }],
    companyUser: [{ required: true, message: "联系人不能为空", trigger: "blur" }],
    companyPhone: [{ required: true, message: "手机号码不能为空", trigger: "blur" }, {
      pattern: /^1[3|4|5|6|7|8|9][0-9]\d{8}$/, message: "请输入正确的手机号码", trigger: "blur"
    }],
    companyCode: [{ required: true, message: "统一社会信用代码不能为空", trigger: "blur" }],
    companyImg: [{ required: true, message: "营业执照不能为空", trigger: "blur" }],
    companyAddress: [{ required: true, message: "企业地址不能为空", trigger: "blur" }],

    // email: [{ type: "email", message: "请输入正确的邮箱地址", trigger: ["blur", "change"] }],
    // phone: [{ pattern: /^1[3|4|5|6|7|8|9][0-9]\d{8}$/, message: "请输入正确的手机号码", trigger: "blur" }],
  },
});

const { queryParams, form, rules } = toRefs(data);
// const dispDeptType = computed(() => (e) => {
//   return dept_type.value.find((f) => f.value == e).label;
// });
const recordRow = ref([])
/** 查询企业列表 */
function getList() {
  loading.value = true;
  listCompanyLog(queryParams.value).then((response) => {
    deptList.value = response.rows
    data.queryParams.total = response.total
    loading.value = false;
  });
}
/** 取消按钮 */
function cancel() {
  open.value = false;
  reset();
  getList();
}
/** 表单重置 */
function reset() {
  form.value = {
    deptId: undefined,
    parentId: undefined,
    deptName: undefined,
    orderNum: 0,
    leader: undefined,
    phone: undefined,
    email: undefined,
    status: "0",
    deptType: undefined,
  };
  proxy.resetForm("deptRef");
}
const queryRef = ref()
/** 搜索按钮操作 */
function handleQuery() {
  getList();
}
/** 重置按钮操作 */
function resetQuery() {
  queryRef.value.resetFields();
  handleQuery();
}
/** 新增按钮操作 */
function handleAdd(row) {
  if(row) {
    form.value = row
    title.value = "编辑企业";
  } else {
    form.value = {
      companyStatus: 0
    }
    title.value = "添加企业";
  }
  open.value = true;
}

/** 提交按钮 */
function submitForm() {
  proxy.$refs["deptRef"].validate((valid) => {
    if (valid) {
      if (form.value.companyId != undefined) {
        updCompanyLog(form.value).then((response) => {
          proxy.$modal.msgSuccess("修改成功");
          open.value = false;
          getList();
        });
      } else {
        addCompany(form.value).then((response) => {
          proxy.$modal.msgSuccess("新增成功");
          open.value = false;
          getList();
        });
      }
    }
  });
}
/** 删除按钮操作 */
function handleDelete(row) {
  proxy.$modal
    .confirm('是否确认删除该数据?')
    .then(function () {
      return delCompanyLog({delId: row.id});
    })
    .then(() => {
      getList();
      proxy.$modal.msgSuccess("删除成功");
    })
    .catch(() => {});
}
// 修改企业信息
function changeCompanyNews(row, event) {
  if(loading.value){
    return
  }
  updStatus(row).then(val => {
    proxy.$modal.msgSuccess("修改成功");
    getList();
  })
}
// 导入模板
function exportExcel() {
  exporttem.value.openDialog()
}
// 导入记录
function exportRecordComOpen() {
  exportRecordCom.value.openDialog()
}
function resList(row) {
  recordRow.value = row
  exportRecordCom.value.openDialog()
}
function checkJudge(row) {
  judgeComRef.value.openDialog(row)
}
function createQrcodeHandler(row) {
  createQrcodeRef.value.openDialog(row)
}
getList();
</script>

<style scoped lang="scss">
.evenly-distributed-labels {
  :deep(){
    .el-form-item__label {
      position: relative; /* 设置相对定位作为星号的定位基准 */
      text-align: justify;
      text-align-last: justify; /* 确保最后一行也两端对齐 */
      padding-left: 10px; /* 为星号预留空间 */
      display: inline-block;
    }
  }
} 


</style>
